@@ -1,7 +1,8 @@
 
 class Measure(object):
 
-    def __init__(self, label, type='float'): #TODO support type='integer'
+    def __init__(self, label, type='float'):
+        self.type = type
         self.label = label
         self._db = None
 
